package com.xy.service;

import com.xy.entity.MercFeeSettle;
import com.xy.mapper.MercFeeSettleMapper;
import com.xy.service.MercFeeSettleService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;

import java.util.List;
import com.xy.utils.R;
import com.xy.utils.PageBean;
import com.xy.dto.MercFeeSettleDto;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.PostMapping;
import io.swagger.annotations.ApiOperation;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.xy.utils.MybatisPlusQuery;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.validation.annotation.Validated;
import com.xy.utils.Emptys;

import static com.xy.utils.Beans.copy;
import static com.xy.utils.PlusBeans.toIPage;
import static com.xy.utils.PlusBeans.toPageBean;


/**
* <p>
* 商户佣金费用结算 服务实现类
* </p>
*
* @author 谭斌
* @since 2024-04-23
*/
@Service
@AllArgsConstructor
@Api(tags = "商户佣金费用结算")
public class MercFeeSettleServiceImpl extends ServiceImpl<MercFeeSettleMapper, MercFeeSettle> implements MercFeeSettleService {

    @PostMapping("obj")
    @ApiOperation("对象查询")
    public R<MercFeeSettleDto.Vo> obj(@RequestBody MercFeeSettleDto.Vo vo) {
        MercFeeSettleDto.SelectList selectList = copy(MercFeeSettleDto.SelectList.class, vo);
        List<MercFeeSettleDto.Vo> list = list(selectList).getData();
        if(Emptys.check(list)) {
            return R.ok(list.get(0));
        }
        return R.ok();
    }

    @PostMapping("list")
    @ApiOperation("集合查询")
    public R<List<MercFeeSettleDto.Vo>> list(@RequestBody MercFeeSettleDto.SelectList selectList) {
        LambdaQueryWrapper<MercFeeSettle> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(selectList, MercFeeSettle.class).build();
        List<MercFeeSettle> list = list(lambdaQueryWrapper);
        return R.ok(copy(MercFeeSettleDto.Vo.class, list));
    }

    @PostMapping("page")
    @ApiOperation("分页查询")
    public R<PageBean<MercFeeSettleDto.Vo>> page(@RequestBody MercFeeSettleDto.Page page) {
        PageBean pageBean = page.getPage();
        LambdaQueryWrapper<MercFeeSettle> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(page, MercFeeSettle.class).build();
        IPage<MercFeeSettle> iPage = page(toIPage(pageBean), lambdaQueryWrapper);
        return R.ok(toPageBean(MercFeeSettleDto.Vo.class, iPage));
    }

    @PostMapping("save")
    @ApiOperation("添加")
    public R save(@RequestBody @Validated MercFeeSettleDto.Save save) {
        MercFeeSettle saveInfo = copy(MercFeeSettle.class, save);
        save(saveInfo);
        return R.ok();
    }

    @PostMapping("update")
    @ApiOperation("修改")
    public R update(@RequestBody @Validated MercFeeSettleDto.Update update) {
        MercFeeSettle updateInfo = copy(MercFeeSettle.class, update);
        updateById(updateInfo);
        return R.ok();
    }
}